sqlobject.tests.test_uuidcol module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_uuidcol module

class `sqlobject.tests.test_uuidcol.` `UuidContainer`(**kw)

  Bases: `sqlobject.main.SQLObject`

  `j` = uuid_container
  `q` = uuid_container
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_uuidcol.UuidContainer`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'uuid_container'
  property `uuiddata`

`sqlobject.tests.test_uuidcol.` `test_uuidCol`()